{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "arvados/l7g"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 2,
                    "coresMax": 2,
                    "ramMin": 13000
                }
            ],
            "hints": [
                {
                    "keep_cache": 4096,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "baseCommand": "bash",
            "inputs": [
                {
                    "type": "File",
                    "label": "Compressed assembly fixed width file",
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#convertgvcf.cwl/afn"
                },
                {
                    "type": "File",
                    "label": "Compressed mitochondrial assembly fixed width file",
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#convertgvcf.cwl/afnM"
                },
                {
                    "type": "File",
                    "label": "Assembly index file",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#convertgvcf.cwl/aidx"
                },
                {
                    "type": "File",
                    "label": "Mitochondrial assembly index file",
                    "inputBinding": {
                        "position": 11
                    },
                    "id": "#convertgvcf.cwl/aidxM"
                },
                {
                    "type": "File",
                    "label": "Master script to create a FastJ for each gVCF",
                    "default": {
                        "class": "File",
                        "location": "https://raw.githubusercontent.com/curoverse/l7g/2d067e70af7c1a49a2a015ddcd0d859b0b885e98/cwl-version/convert2fastj/gvcf_version/src/convert2fastjCWL"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#convertgvcf.cwl/bashscript"
                },
                {
                    "type": "Directory",
                    "label": "Directory of input gVCFs",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#convertgvcf.cwl/gffDir"
                },
                {
                    "type": "string",
                    "label": "Prefix of all gVCF files",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#convertgvcf.cwl/gffPrefix"
                },
                {
                    "type": "string",
                    "label": "Lightning application for parsing and searching assembly files",
                    "default": "/usr/local/bin/l7g",
                    "inputBinding": {
                        "position": 14
                    },
                    "id": "#convertgvcf.cwl/l7g"
                },
                {
                    "type": "string",
                    "label": "Tool for streaming and converting variant call formats",
                    "default": "/usr/local/bin/pasta",
                    "inputBinding": {
                        "position": 15
                    },
                    "id": "#convertgvcf.cwl/pasta"
                },
                {
                    "type": "string",
                    "label": "Reference genome",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#convertgvcf.cwl/ref"
                },
                {
                    "type": "string",
                    "label": "Mitochondrial reference genome",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#convertgvcf.cwl/refM"
                },
                {
                    "type": "File",
                    "label": "Reference genome in FASTA format",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#convertgvcf.cwl/reffa"
                },
                {
                    "type": "File",
                    "label": "Reference mitochondrial genome in FASTA format",
                    "inputBinding": {
                        "position": 9
                    },
                    "id": "#convertgvcf.cwl/reffaM"
                },
                {
                    "type": "string",
                    "label": "Tool for streaming and converting variant call formats",
                    "default": "/usr/local/bin/refstream",
                    "inputBinding": {
                        "position": 16
                    },
                    "id": "#convertgvcf.cwl/refstream"
                },
                {
                    "type": "string",
                    "label": "Mitochondrial naming scheme for gVCF",
                    "inputBinding": {
                        "position": 12
                    },
                    "id": "#convertgvcf.cwl/seqidM"
                },
                {
                    "type": "File",
                    "label": "Compressed tagset in FASTA format",
                    "inputBinding": {
                        "position": 13
                    },
                    "id": "#convertgvcf.cwl/tagdir"
                },
                {
                    "type": "string",
                    "label": "Tool to extract information from the tile assembly files",
                    "default": "/usr/local/bin/tile-assembly",
                    "inputBinding": {
                        "position": 17
                    },
                    "id": "#convertgvcf.cwl/tile_assembly"
                }
            ],
            "id": "#convertgvcf.cwl",
            "outputs": [
                {
                    "type": "Directory",
                    "label": "Directories of FastJs",
                    "outputBinding": {
                        "glob": "stage/*"
                    },
                    "id": "#convertgvcf.cwl/out1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "label": "Indexed and zipped gVCFs",
                    "outputBinding": {
                        "glob": "indexed/*.gz*"
                    },
                    "id": "#convertgvcf.cwl/out2"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "label": "Create list of gVCF directories to process",
            "hints": [
                {
                    "loadListing": "shallow_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "label": "Directory of Input gVCFs",
                    "id": "#getdirs.cwl/refdirectory"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "label": "Array of gVCF directories",
                    "id": "#getdirs.cwl/out1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "label": "Array of basenames for gVCF directories",
                    "id": "#getdirs.cwl/out2"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "expression": "${\n  var samples = [];\n  var samplenames = [];\n  for (var i = 0; i < inputs.refdirectory.listing.length; i++) {\n    var name = inputs.refdirectory.listing[i];\n    var type = name.class;\n    var basename = name.basename;\n     if (type === 'Directory') {\n            samples.push(name);\n            samplenames.push(basename);\n          }\n  }\n  return {\"out1\": samples,\"out2\": samplenames};\n}\n",
            "id": "#getdirs.cwl"
        },
        {
            "class": "Workflow",
            "label": "Creates a FastJ file for each gVCF by path",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "arvados/l7g"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 2,
                    "coresMax": 2
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "keep_cache": 4096,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "shallow_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Compressed assembly fixed width file",
                    "id": "#main/afn"
                },
                {
                    "type": "File",
                    "label": "Compressed mitochondrial assembly fixed width file",
                    "id": "#main/afnM"
                },
                {
                    "type": "File",
                    "label": "Assembly index file",
                    "id": "#main/aidx"
                },
                {
                    "type": "File",
                    "label": "Mitochondrial assembly index file",
                    "id": "#main/aidxM"
                },
                {
                    "type": "string",
                    "label": "Reference genome",
                    "id": "#main/ref"
                },
                {
                    "type": "string",
                    "label": "Mitochondrial reference genome",
                    "id": "#main/refM"
                },
                {
                    "type": "Directory",
                    "label": "Directory of input gVCFs",
                    "id": "#main/refdirectory"
                },
                {
                    "type": "File",
                    "label": "Reference genome in FASTA format",
                    "id": "#main/reffa"
                },
                {
                    "type": "File",
                    "label": "Reference mitochondrial genome in FASTA format",
                    "id": "#main/reffaM"
                },
                {
                    "type": "string",
                    "label": "Mitochondrial naming scheme for gVCF",
                    "id": "#main/seqidM"
                },
                {
                    "type": "File",
                    "label": "Compressed tagset in FASTA format",
                    "id": "#main/tagdir"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "label": "Directories of FastJs",
                    "outputSource": "#main/step2/out1",
                    "id": "#main/out1"
                }
            ],
            "steps": [
                {
                    "run": "#getdirs.cwl",
                    "in": [
                        {
                            "source": "#main/refdirectory",
                            "id": "#main/step1/refdirectory"
                        }
                    ],
                    "out": [
                        "#main/step1/out1",
                        "#main/step1/out2"
                    ],
                    "id": "#main/step1"
                },
                {
                    "scatter": [
                        "#main/step2/gffDir",
                        "#main/step2/gffPrefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/afn",
                            "id": "#main/step2/afn"
                        },
                        {
                            "source": "#main/afnM",
                            "id": "#main/step2/afnM"
                        },
                        {
                            "source": "#main/aidx",
                            "id": "#main/step2/aidx"
                        },
                        {
                            "source": "#main/aidxM",
                            "id": "#main/step2/aidxM"
                        },
                        {
                            "source": "#main/step1/out1",
                            "id": "#main/step2/gffDir"
                        },
                        {
                            "source": "#main/step1/out2",
                            "id": "#main/step2/gffPrefix"
                        },
                        {
                            "source": "#main/ref",
                            "id": "#main/step2/ref"
                        },
                        {
                            "source": "#main/refM",
                            "id": "#main/step2/refM"
                        },
                        {
                            "source": "#main/reffa",
                            "id": "#main/step2/reffa"
                        },
                        {
                            "source": "#main/reffaM",
                            "id": "#main/step2/reffaM"
                        },
                        {
                            "source": "#main/seqidM",
                            "id": "#main/step2/seqidM"
                        },
                        {
                            "source": "#main/tagdir",
                            "id": "#main/step2/tagdir"
                        }
                    ],
                    "run": "#convertgvcf.cwl",
                    "out": [
                        "#main/step2/out1",
                        "#main/step2/out2"
                    ],
                    "id": "#main/step2"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "arv": "http://arvados.org/cwl#",
        "cwltool": "http://commonwl.org/cwltool#"
    }
}
